<?php

/**
 * @file
 * Contains \DrupalProject\composer\ScriptHandler.
 */

namespace DrupalProject\composer;

use Symfony\Component\Filesystem\Filesystem;

class ScriptHandler {

  protected static function getDrupalRoot($project_root) {
    return $project_root .  '/web';
  }

  public static function createRequiredFiles() {
    $fs = new Filesystem();
    $root = getcwd();
    $drupalRoot = static::getDrupalRoot($root);

    foreach (['modules', 'profiles', 'themes', ] as $dir) {
      if (!$fs->exists($drupalRoot . '/'. $dir)) {
        $fs->mkdir($drupalRoot . '/'. $dir);
      }
    }

    foreach (['config/default/live', 'config/default/staging', 'config/default/sync', 'settings/default', 'files/default/files', 'files/default/private', ] as $dir) {
      if (!$fs->exists($root . '/'. $dir)) {
        $fs->mkdir($root . '/'. $dir);
        $fs->copy($root . '/scripts/boilerplate/.htaccess', $root . '/' . $dir . '/.htaccess');
      }
    }

    foreach (['files', 'private', ] as $dir) {
      if (!$fs->exists($drupalRoot . '/sites/default/' . $dir)) {
        $fs->symlink($root . '/files/default/' . $dir, $drupalRoot . '/sites/default/' . $dir);
        $fs->chmod($drupalRoot . '/sites/default/' . $dir, 0755);
      }
    }

    foreach (['settings.php', 'services.yml', 'settings.local.php', ] as $template) {
      if (!$fs->exists($drupalRoot . '/sites/default/' . $template)) {
        $fs->copy($root . '/scripts/boilerplate/template.' . $template, $root . '/settings/default/' . $template);
        $fs->symlink($root . '/settings/default/' . $template, $drupalRoot . '/sites/default/' . $template);
        $fs->chmod($drupalRoot . '/sites/default/' . $template, 0666);
      }
    }

    if (!$fs->exists($drupalRoot . '/sites/default/files/config')) {
      $fs->symlink($root . '/config/default', $drupalRoot . '/sites/default/files/config');
    }

  }

}
